@@ -9,7 +9,7 @@ Use it for control a static's versions.
 
 """
 
-__version__ = '0.1.5'
+__version__ = '0.3'
 __project__ = __name__
-__author__ = "Sinan Midillili <sinan@hipo.biz>"
-__license__ = "BSD"
\ No newline at end of file
+__author__ = "Sinan Midillili <sinanm89@gmail.com>"
+__license__ = "MIT"
\ No newline at end of file
